@@ -10,7 +10,7 @@ mod daemon_create;
 mod daemon_invoke;
 mod daemon_widthdraw;
 mod fee_collect;
-mod health_check;
+mod health_ping;
 mod task_cancel;
 mod task_create;
 mod task_execute;
@@ -27,7 +27,7 @@ pub use daemon_create::*;
 pub use daemon_invoke::*;
 pub use daemon_widthdraw::*;
 pub use fee_collect::*;
-pub use health_check::*;
+pub use health_ping::*;
 pub use task_cancel::*;
 pub use task_create::*;
 pub use task_execute::*;
